<?php

declare(strict_types=1);

namespace Dedi\SyliusBlogPlugin\Entity;

use Doctrine\ORM\Mapping as ORM;
use Gedmo\Mapping\Annotation as Gedmo;
use Sylius\Component\Resource\Model\ResourceInterface;
use Symfony\Bridge\Doctrine\Validator\Constraints\UniqueEntity;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * @ORM\Entity()
 * @ORM\Table(name="dedi_blog_category_translation")
 * @UniqueEntity(fields={"slug"})
 */
class CategoryTranslation extends AbstractReferableTranslation implements ResourceInterface
{
    /**
     * @ORM\Column(type="integer", nullable=false)
     * @ORM\Id()
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    protected ?int $id = null;

    /**
     * @ORM\Column(type="string", nullable=false, name="category_translation_slug")
     * @Gedmo\Slug(fields={"name"}, unique=true)
     * @Assert\Length(max="255", groups={"default", "sylius"})
     */
    protected ?string $slug = null;

    /**
     * @ORM\Column(type="string", nullable=false, name="category_translation_name")
     * @Assert\NotBlank(groups={"default", "sylius"})
     * @Assert\Length(max="255", groups={"default", "sylius"})
     */
    protected ?string $name = null;

    /**
     * @ORM\Column(type="text", nullable=true, name="category_translation_description")
     */
    protected ?string $description = null;

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getSlug(): ?string
    {
        return $this->slug;
    }

    public function setSlug(?string $slug): self
    {
        $this->slug = $slug;

        return $this;
    }

    public function getName(): ?string
    {
        return $this->name;
    }

    public function setName(?string $name): self
    {
        $this->name = $name;

        return $this;
    }

    public function getDescription(): ?string
    {
        return $this->description;
    }

    public function setDescription(?string $description): self
    {
        $this->description = $description;

        return $this;
    }
}
